@@ -27,6 +27,7 @@ from singer.messages import (
     StateMessage,
     format_message,
     parse_message,
+    write_message,
     write_record,
     write_records,
     write_schema,
@@ -45,6 +46,15 @@ from singer.transform import (
 from singer.catalog import Catalog
 from singer.schema import Schema
 
+from singer.bookmarks import (
+    write_bookmark,
+    get_bookmark,
+    set_offset,
+    clear_offset,
+    get_offset,
+    set_currently_syncing,
+    get_currently_syncing,
+)
 
 if __name__ == "__main__":
     import doctest
